@@ -12,11 +12,11 @@ use Memoize;
 
 =head1 VERSION
 
-Version 1.402.9
+Version 1.403.2
 
 =cut
 
-our $VERSION = '1.402.9';
+our $VERSION = '1.403.2';
 
 my %typeregistry = (
     default => {},
@@ -302,8 +302,7 @@ sub call_procedure {
                       local ($@);
                       $arg = $arg->to_db if eval {$arg->can('to_db')};
                       $arg = $arg->pgobject_to_db if eval {$arg->can('pgobject_to_db')};
-                      no warnings 'uninitialized';
-                      ref($arg) =~ /HASH/ ? $arg->{value} : $arg;
+                      $arg;
                 }  @{$args{args}};
 
     my $argstr = join ', ', map { 
@@ -313,8 +312,10 @@ sub call_procedure {
     my $order = '';
     if ($args{orderby}){
         $order = join(', ', map {
-                                  $_ =~ s/\s+(ASC|DESC)$//i;
-                                  my $dir = $1;
+                                  my $dir = undef;
+                                  if ( s/\s+(ASC|DESC)\s*$//i ) {
+                                      $dir = $1;
+                                  }
                                   defined $dir ? $dbh->quote_identifier($_)
                                                   . " $dir"
                                                : $dbh->quote_identifier($_);
@@ -333,9 +334,6 @@ sub call_procedure {
 
     my $place = 1;
 
-    # This is needed to support byteas, which rquire special escaping during
-    # the binding process.  --Chris T
-
     foreach my $carg (@qargs){
         if (ref($carg) =~ /HASH/){
             $sth->bind_param($place, $carg->{value},
@@ -660,7 +658,7 @@ L<http://search.cpan.org/dist/PGObject/>
 This code has been loosely based on code written for the LedgerSMB open source 
 accounting and ERP project.  While that software uses the GNU GPL v2 or later,
 this is my own reimplementation, based on my original contributions to that 
-project alone, and it differs in signficant ways.   This being said, without
+project alone, and it differs in significant ways.   This being said, without
 LedgerSMB, this module wouldn't exist, and without the lessons learned there, 
 and the great people who have helped make this possible, this framework would 
 not be half of what it is today.
